.. _community_guidelines:
.. index:: Community Guidelines

Community guidelines
********************

* Contributions to :program:`PyDFT` are always welcome and appreciated. Before doing
  so, please first read the `CONTRIBUTING <https://gitlab.tue.nl/ifilot/pydft/py/blob/master/CONTRIBUTING.md>`_
  guide.
* For reporting issues or problems with the software, you are kindly invited to
  `to open a new issue on Gitlab <https://gitlab.tue.nl/ifilot/pydft/-/issues/new>`_.
* If you wish to contact the developers, please send an e-mail to i.a.w.filot@tue.nl.
